require "import"
import "android.widget.*"
import "android.view.View"
import "android.content.Context"
import "android.os.Environment"
import "java.io.File"
import "java.io.FileOutputStream"
import "cjson"
import "java.net.URLEncoder"

activity = this

function writeToFile(path, content)
    local file = io.open(path, "wb")
    if file then
        file:write(content)
        file:close()
        return true
    end
    return false
end

function saveVideoToFile(videoData, videoTitle)
    if not videoTitle or videoTitle == "" then return nil end
    local baseFolderPath = Environment.getExternalStorageDirectory().getPath().. "/Download/CapCutVideos"
    local folder = File(baseFolderPath)
    if not folder.exists() then folder.mkdirs() end

    local sanitizedTitle = videoTitle:gsub("[^%w_%-]", "_")
    local fileName = sanitizedTitle.. ".mp4"
    local filePath = baseFolderPath.. "/".. fileName

    if writeToFile(filePath, videoData) then return filePath end
    return nil
end

function downloadCapCutVideo(url, callback)
    if not url then callback(nil, nil, "URL tidak valid") return end
    local apiUrl = "https://api.vreden.my.id/api/capcutdl?url=".. URLEncoder.encode(url, "UTF-8")

    Http.get(apiUrl, {}, function(code, content)
        if code == 200 then
            local jsonResponse = cjson.decode(content)
            if jsonResponse and jsonResponse.result then
                local result = jsonResponse.result
                local videoTitle = result.title
                local videoUrl = result.url

                -- Menampilkan detail video
                detailText.text = "🎬 **Judul**: ".. videoTitle

                service.speak("Detail video berhasil diperoleh.")

                -- Tampilkan tombol Simpan File
                saveButton.visibility = View.VISIBLE

                -- Simpan video
                saveButton.onClick = function()
                    service.speak("Mengunduh dan menyimpan video...")
                    Http.get(videoUrl, {}, function(videoCode, videoContent)
                        if videoCode == 200 then
                            local savedPath = saveVideoToFile(videoContent, videoTitle)
                            if savedPath then
                                service.speak("Video telah disimpan di ".. savedPath)
                            else
                                service.speak("Gagal menyimpan video!")
                            end
                        else
                            service.speak("Gagal mengunduh video: ".. videoCode)
                        end
                    end)
                end
            else
                service.speak("Data API tidak sesuai")
            end
        else
            service.speak("Gagal mengakses API: ".. code)
        end
    end)
end

layout = {
    ScrollView,
    layout_width = "fill",
    layout_height = "fill",
    {
        LinearLayout,
        orientation = "vertical",
        layout_width = "fill",
        padding = "16dp",
        layout_height = "wrap_content",
        {
            EditText,
            id = "urlInput",
            hint = "Masukkan URL CapCut",
            layout_width = "fill",
            layout_height = "wrap_content",
            inputType = "text"
},
        {
            Button,
            id = "downloadButton",
            text = "Dapatkan Detail",
            layout_width = "fill",
            layout_height = "wrap_content"
},
        {
            TextView,
            id = "detailText",
            text = "",
            layout_width = "fill",
            layout_height = "wrap_content",
            padding = "10dp"
},
        {
            Button,
            id = "saveButton",
            text = "Simpan File",
layout_width = "fill",
            layout_height = "wrap_content",
            visibility = View.GONE
}
}
}

dlg = LuaDialog(this)
dlg.setTitle("Pengunduh Video CapCut")
dlg.setView(loadlayout(layout))

downloadButton.onClick = function()
    local url = urlInput.text

    if #url == 0 then
        service.speak("Masukkan URL CapCut!") return
    end

    service.speak("Mengambil detail video...")

    downloadCapCutVideo(url, function() end)
end
-- Tombol untuk menutup dialog
dlg.setButton("Tutup", function()
    dlg.dismiss()
end)

dlg.show()