require "import"
import "android.widget.*"
import "android.view.View"
import "android.content.Context"
import "android.os.Environment"
import "java.io.File"
import "java.io.FileOutputStream"
import "cjson"
import "java.net.URLEncoder"

activity = this

function writeToFile(path, content)
    local file = io.open(path, "wb")
    if file then
        file:write(content)
        file:close()
        return true
    end
    return false
end

function saveFile(data, fileName, extension)
    if not fileName or fileName == "" then return nil end
    local baseFolderPath = Environment.getExternalStorageDirectory().getPath().. "/Download/TikTokDownloads"
    local folder = File(baseFolderPath)
    if not folder.exists() then folder.mkdirs() end

    local sanitizedTitle = fileName:gsub("[^%w_%-]", "_")
    local fullFileName = sanitizedTitle.. ".".. extension
    local filePath = baseFolderPath.. "/".. fullFileName

    if writeToFile(filePath, data) then return filePath end
    return nil
end

function downloadTikTokVideo(url, callback)
    if not url then callback(nil, "URL tidak valid") return end
    local apiUrl = "https://api.vreden.my.id/api/tiktok?url=".. URLEncoder.encode(url, "UTF-8")

    Http.get(apiUrl, {}, function(code, content)
        if code == 200 then
            local jsonResponse = cjson.decode(content)
            if jsonResponse and jsonResponse.result then
                local result = jsonResponse.result
                local videoTitle = result.title
                local takenAt = result.taken_at
                local region = result.region
                local views = result.stats.views
                local likes = result.stats.likes
                local comments = result.stats.comment
                local shares = result.stats.share
                local musicTitle = result.music_info.title
                local musicAuthor = result.music_info.author
                local videoUrlNormal = result.data[1].url -- MP4 kualitas biasa
                local videoUrlHD = result.data[2].url -- MP4 kualitas HD
                local audioUrl = result.music_info.url -- MP3

                -- Menampilkan detail video
                detailText.text = "**Judul**: ".. videoTitle..
                                  "\n**Diunggah pada**: ".. takenAt..
                                  "\n**Wilayah**: ".. region..
                                  "\n**Tayangan**: ".. views..
                                  "\n**Suka**: ".. likes..
                                  "\n**Komentar**: ".. comments..
                                  "\n**Bagikan**: ".. shares..
                                  "\n**Musik**: ".. musicTitle.. " - ".. musicAuthor

                service.speak("Detail video berhasil diperoleh.")

                -- Menampilkan tombol Simpan File
                saveMP3Button.visibility = View.VISIBLE
                saveMP4NormalButton.visibility = View.VISIBLE
                saveMP4HDButton.visibility = View.VISIBLE

                -- Simpan sebagai MP3
                saveMP3Button.onClick = function()
                    service.speak("Mengunduh dan menyimpan audio...")
                    Http.get(audioUrl, {}, function(audioCode, audioContent)
                        if audioCode == 200 then
                            local savedPath = saveFile(audioContent, videoTitle, "mp3")
                            if savedPath then
                                service.speak("Audio telah disimpan di ".. savedPath)
                            else
                                service.speak("Gagal menyimpan audio!")
                            end
                        else
                            service.speak("Gagal mengunduh audio: ".. audioCode)
                        end
                    end)
end

                -- Simpan sebagai MP4 (Kualitas Biasa)
                saveMP4NormalButton.onClick = function()
                    service.speak("Mengunduh dan menyimpan video kualitas biasa...")
                    Http.get(videoUrlNormal, {}, function(videoCode, videoContent)
                        if videoCode == 200 then
                            local savedPath = saveFile(videoContent, videoTitle, "mp4")
                            if savedPath then
                                service.speak("Video kualitas biasa telah disimpan di ".. savedPath)
                            else
                                service.speak("Gagal menyimpan video!")
                            end
                        else
                            service.speak("Gagal mengunduh video: ".. videoCode)
                        end
                    end)
                end

                -- Simpan sebagai MP4 (Kualitas HD)
                saveMP4HDButton.onClick = function()
                    service.speak("Mengunduh dan menyimpan video kualitas HD...")
                    Http.get(videoUrlHD, {}, function(videoCode, videoContent)
                        if videoCode == 200 then
                            local savedPath = saveFile(videoContent, videoTitle.."_HD", "mp4")
                            if savedPath then
                                service.speak("Video kualitas HD telah disimpan di ".. savedPath)
                            else
                                service.speak("Gagal menyimpan video!")
                            end
                        else
                            service.speak("Gagal mengunduh video: ".. videoCode)
                        end
                    end)
                end
            else
                service.speak("Data API tidak sesuai")
            end
        else
            service.speak("Gagal mengakses API: ".. code)
        end
    end)
end

layout = {
    ScrollView,
    layout_width = "fill",
    layout_height = "fill",
    {
        LinearLayout,
        orientation = "vertical",
        layout_width = "fill",
        padding = "16dp",
        layout_height = "wrap_content",
      {
        Button,
        text = "Tentang",
        layout_width = "match",
        layout_height = "wrap_content",
        layout_margin = "16dp",
onClick = function()
dev()
end
      },
        {
            EditText,
            id = "urlInput",
            hint = "Masukkan URL TikTok",
            layout_width = "fill",
            layout_height = "wrap_content",
            inputType = "text"
},
        {
            Button,
            id = "downloadButton",
            text = "Dapatkan Detail",
            layout_width = "fill",
            layout_height = "wrap_content"
},
        {
            TextView,
            id = "detailText",
            text = "",
            layout_width = "fill",
            layout_height = "wrap_content",
            padding = "10dp"
},
        {
            Button,
            id = "saveMP3Button",
            text = "Simpan sebagai MP3",
            layout_width = "fill",
            layout_height = "wrap_content",
            visibility = View.GONE
},
        {
            Button,
            id = "saveMP4NormalButton",
            text = "Simpan sebagai MP4 (Kualitas Biasa)",
            layout_width = "fill",
            layout_height = "wrap_content",
            visibility = View.GONE
},
        {
            Button,
            id = "saveMP4HDButton",
            text = "Simpan sebagai MP4 (Kualitas HD)",
            layout_width = "fill",
            layout_height = "wrap_content",
            visibility = View.GONE
}
}
}

function dev()
    local aboutLayout = {
        ScrollView,
        layout_width = "fill",
        layout_height = "fill",
        backgroundColor = 0xFF121212,
        {
            LinearLayout,
            orientation = "vertical",
            layout_width = "fill",
            layout_height = "wrap",
            padding = "16dp",
            {
                TextView,
                text = "Bergabung ke saluran saya untuk mendapatkan alat plugin Jieshuo lainnya.\n\nRequest report, dll tentang ekstensi. Silakan hubungi saya",
                layout_width = "fill",
                layout_height = "wrap_content",
                textSize = "20sp",
                textColor = 0xFFFFFFFF,
                gravity = "center",
                backgroundColor = 0xFF6200EE,
                padding = "12dp"
},
            {
                Button,
                text = "Contact Developer",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFF03DAC5,
                textColor = 0xFF000000,
                padding = "12dp",
                onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("tg://resolve?domain=jibomico")))
                    end)
                    service.speak("Membuka Telegram...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
},
            {
                Button,
                text = "Bergabung ke channel Telegram",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFFBB86FC,
                textColor = 0xFFFFFFFF,
                padding = "12dp",
                onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("tg://resolve?domain=jieshuojm")))
                    end)
                    service.speak("Membuka channel Telegram...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
},
            {
                Button,
                text = "Bergabung ke grup WhatsApp",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFF6200EE,
                textColor = 0xFFFFFFFF,
                padding = "12dp",
onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("https://chat.whatsapp.com/EXsCeLRcy9I3njvaqeIn7x")))
                    end)
                    service.speak("Membuka grup WhatsApp...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
}
}
}

    aboutDlg = LuaDialog(activity)
    aboutDlg.setTitle("Developed by Jm")
    aboutDlg.setView(loadlayout(aboutLayout))
    aboutDlg.setButton("Ok", function()
        aboutDlg.dismiss()
        vibrate()
    end)
    aboutDlg.show()
end

dlg = LuaDialog(this)
dlg.setTitle("Pengunduh Video TikTok")
dlg.setView(loadlayout(layout))

downloadButton.onClick = function()
    local url = urlInput.text

    if #url == 0 then
        service.speak("Masukkan URL TikTok!") return
    end

    service.speak("Mengambil detail video...")

    downloadTikTokVideo(url, function() end)
end
-- Tombol untuk menutup dialog
dlg.setButton("Tutup", function()
    dlg.dismiss()
end)

dlg.show()
