require "import"
import "android.widget.*"
import "android.text.InputType"
import "android.view.View"
import "android.content.Context"
import "android.os.Environment"
import "java.io.File"
import "java.io.FileOutputStream"
import "cjson"
import "java.net.URLEncoder"

activity = this

function writeToFile(path, content)
    local file = io.open(path, "wb")
    if file then
        file:write(content)
        file:close()
        return true
    end
    return false
end

function saveFileToStorage(fileData, fileName)
    if not fileName or fileName == "" then return nil end
    local baseFolderPath = Environment.getExternalStorageDirectory().getPath().. "/Download/GoogleDriveFiles"
    local folder = File(baseFolderPath)
    if not folder.exists() then folder.mkdirs() end

    local sanitizedTitle = fileName:gsub("[^%w_%-%.]", "_")
    local filePath = baseFolderPath.. "/".. sanitizedTitle

    if writeToFile(filePath, fileData) then return filePath end
    return nil
end

function downloadGoogleDriveFile(url)
    if not url then
        service.speak("URL tidak valid!")
        return
    end

    local apiUrl = "https://api.vreden.my.id/api/drive?url=".. URLEncoder.encode(url, "UTF-8")

    Http.get(apiUrl, {}, function(code, content)
        if code == 200 then
            local jsonResponse = cjson.decode(content)
            if jsonResponse and jsonResponse.result and jsonResponse.result.status then
                local fileInfo = jsonResponse.result
                local downloadUrl = fileInfo.downloadUrl
                local fileName = fileInfo.fileName or "DownloadedFile"
                local fileSize = tonumber(fileInfo.sizeBytes) / (1024 * 1024).. " MB"
                local uploaderName = fileInfo.uploader.name
                local uploaderEmail = fileInfo.uploader.email
                local uploaderProfile = fileInfo.uploader.profile

                -- Menampilkan detail file
                detailText.text = "**Nama File:** ".. fileName..
                                  "\n**Ukuran:** ".. fileSize..
                                  "\n**Uploader:** ".. uploaderName.. " (".. uploaderEmail.. ")"..
                                  "\n**Status Scan:** ".. fileInfo.scanResult..
                                  "\n**Link Unduhan:** ".. downloadUrl

                -- Tampilkan tombol simpan secara dinamis
                saveButton.visibility = View.VISIBLE
                saveButton.onClick = function()
                    service.speak("Mengunduh file ".. fileName.. "...")

                    Http.get(downloadUrl, {}, function(fileCode, fileContent)
                        if fileCode == 200 then
                            local savedPath = saveFileToStorage(fileContent, fileName)
                            if savedPath then
                                service.speak("File telah disimpan di ".. savedPath)
                            else
                                service.speak("Gagal menyimpan file!")
                            end
                        else
                            service.speak("Gagal mengunduh file: ".. fileCode)
                        end
                    end)
                end
            else
                service.speak("Data API tidak sesuai")
            end
        else
            service.speak("Gagal mengakses API: ".. code)
        end
    end)
end

layout = {
    ScrollView,
    layout_width = "fill",
    layout_height = "fill",
    {
        LinearLayout,
        orientation = "vertical",
        layout_width = "fill",
        padding = "16dp",
        layout_height = "wrap_content",
        {
            EditText,
            id = "urlInput",
            hint = "Masukkan URL Google Drive",
            layout_width = "fill",
            layout_height = "wrap_content",
            inputType = InputType.TYPE_CLASS_TEXT
},
        {
            Button,
            id = "downloadButton",
text = "Dapatkan Detail",
            layout_width = "fill",
            layout_height = "wrap_content"
},
        {
            TextView,
            id = "detailText",
            text = "",
            layout_width = "fill",
            layout_height = "wrap_content",
            padding = "10dp"
},
        {
            Button,
            id = "saveButton",
            text = "Simpan File",
            layout_width = "fill",
            layout_height = "wrap_content",
            visibility = View.GONE
}
}
}

dlg = LuaDialog(this)
dlg.setTitle("Pengunduh Google Drive")
dlg.setView(loadlayout(layout))

downloadButton.onClick = function()
    local url = urlInput.text

    if #url == 0 then
        service.speak("Masukkan URL Google Drive!")
        return
    end

    service.speak("Mengambil detail file...")
    downloadGoogleDriveFile(url)
end

dlg.setButton("Tutup", function()
    dlg.dismiss()
end)

dlg.show()