require "import"
import "android.widget.*"
import "android.text.InputType"
import "android.view.View"
import "android.content.Context"
import "android.os.Environment"
import "java.io.File"
import "java.io.FileOutputStream"
import "cjson"
import "java.net.URLEncoder"

activity = this

function writeToFile(path, content)
    local file = io.open(path, "wb")
    if file then
        file:write(content)
        file:close()
        return true
    end
    return false
end

function saveFileToStorage(fileData, fileName)
    if not fileName or fileName == "" then return nil end
    local baseFolderPath = Environment.getExternalStorageDirectory().getPath().. "/Download/MediaFireFiles"
    local folder = File(baseFolderPath)
    if not folder.exists() then folder.mkdirs() end

    local sanitizedTitle = fileName:gsub("[^%w_%-%.]", "_")
    local filePath = baseFolderPath.. "/".. sanitizedTitle

    if writeToFile(filePath, fileData) then return filePath end
    return nil
end

function downloadMediaFireFile(url, callback)
    if not url then
        service.speak("URL tidak valid!")
        return
    end

    local apiUrl = "https://api.vreden.my.id/api/mediafiredl?url=".. URLEncoder.encode(url, "UTF-8")

    Http.get(apiUrl, {}, function(code, content)
        if code == 200 then
            local jsonResponse = cjson.decode(content)
            if jsonResponse and jsonResponse.result and jsonResponse.result[1] and jsonResponse.result[1].status then
                local fileInfo = jsonResponse.result[1]
                local downloadUrl = fileInfo.link
                local fileName = fileInfo.nama or "DownloadedFile"
                local fileSize = fileInfo.size

                detailText.text = "**Nama File:** ".. fileName..
                                  "\n**Ukuran:** ".. fileSize..
                                  "\n**Server:** ".. fileInfo.server..
                                  "\n**Tautan Unduhan:** ".. downloadUrl

                saveButton.visibility = View.VISIBLE
                saveButton.onClick = function()
                    service.speak("Mengunduh file ".. fileName.. "...")

                    Http.get(downloadUrl, {}, function(fileCode, fileContent)
                        if fileCode == 200 then
                            local savedPath = saveFileToStorage(fileContent, fileName)
                            if savedPath then
                                service.speak("File telah disimpan di ".. savedPath)
                            else
                                service.speak("Gagal menyimpan file!")
                            end
                        else
                            service.speak("Gagal mengunduh file: ".. fileCode)
                        end
                    end)
                end
            else
                service.speak("Data API tidak sesuai")
            end
        else
            service.speak("Gagal mengakses API: ".. code)
        end
    end)
end

layout = {
    ScrollView,
    layout_width = "fill",
    layout_height = "fill",
    {
        LinearLayout,
        orientation = "vertical",
        layout_width = "fill",
        padding = "16dp",
        layout_height = "wrap_content",
      {
        Button,
        text = "Tentang",
        layout_width = "match",
        layout_height = "wrap_content",
        layout_margin = "16dp",
onClick = function()
dev()
end
      },
        {
            EditText,
            id = "urlInput",
            hint = "Masukkan URL MediaFire",
            layout_width = "fill",
            layout_height = "wrap_content",
            inputType = InputType.TYPE_CLASS_TEXT
},
        {
            Button,
            id = "downloadButton",
            text = "Dapatkan Detail",
            layout_width = "fill",
            layout_height = "wrap_content"
},
        {
            TextView,
            id = "detailText",
            text = "",
            layout_width = "fill",
            layout_height = "wrap_content",
            padding = "10dp"
},
        {
            Button,
id = "saveButton",
            text = "Simpan File",
            layout_width = "fill",
            layout_height = "wrap_content",
            visibility = View.GONE
}
}
}

function dev()
    local aboutLayout = {
        ScrollView,
        layout_width = "fill",
        layout_height = "fill",
        backgroundColor = 0xFF121212,
        {
            LinearLayout,
            orientation = "vertical",
            layout_width = "fill",
            layout_height = "wrap",
            padding = "16dp",
            {
                TextView,
                text = "Bergabung ke saluran saya untuk mendapatkan alat plugin Jieshuo lainnya.\n\nRequest report, dll tentang ekstensi. Silakan hubungi saya",
                layout_width = "fill",
                layout_height = "wrap_content",
                textSize = "20sp",
                textColor = 0xFFFFFFFF,
                gravity = "center",
                backgroundColor = 0xFF6200EE,
                padding = "12dp"
},
            {
                Button,
                text = "Contact Developer",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFF03DAC5,
                textColor = 0xFF000000,
                padding = "12dp",
                onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("tg://resolve?domain=jibomico")))
                    end)
                    service.speak("Membuka Telegram...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
},
            {
                Button,
                text = "Bergabung ke channel Telegram",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFFBB86FC,
                textColor = 0xFFFFFFFF,
                padding = "12dp",
                onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("tg://resolve?domain=jieshuojm")))
                    end)
                    service.speak("Membuka channel Telegram...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
},
            {
                Button,
                text = "Bergabung ke grup WhatsApp",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFF6200EE,
                textColor = 0xFFFFFFFF,
                padding = "12dp",
onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("https://chat.whatsapp.com/EXsCeLRcy9I3njvaqeIn7x")))
                    end)
                    service.speak("Membuka grup WhatsApp...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
}
}
}

    aboutDlg = LuaDialog(activity)
    aboutDlg.setTitle("Developed by Jm")
    aboutDlg.setView(loadlayout(aboutLayout))
    aboutDlg.setButton("Ok", function()
        aboutDlg.dismiss()
        vibrate()
    end)
    aboutDlg.show()
end

dlg = LuaDialog(this)
dlg.setTitle("Pengunduh MediaFire")
dlg.setView(loadlayout(layout))

downloadButton.onClick = function()
    local url = urlInput.text

    if #url == 0 then
        service.speak("Masukkan URL MediaFire!")
        return
    end

    service.speak("Mengambil detail file...")
    downloadMediaFireFile(url)
end

dlg.setButton("Tutup", function()
    dlg.dismiss()
end)

dlg.show()