require "import"
import "android.widget.*"
import "android.text.InputType"
import "android.view.View"
import "android.content.Context"
import "android.os.Environment"
import "java.io.File"
import "java.io.FileOutputStream"
import "cjson"
import "java.net.URLEncoder"

activity = this

function writeToFile(path, content)
    local file = io.open(path, "wb")
    if file then
        file:write(content)
        file:close()
        return true
    end
    return false
end

function saveVideoToFile(videoData, videoTitle)
    if not videoTitle or videoTitle == "" then return nil end
    local baseFolderPath = Environment.getExternalStorageDirectory().getPath().. "/Download/InstagramVideos"
    local folder = File(baseFolderPath)
    if not folder.exists() then folder.mkdirs() end

    local sanitizedTitle = videoTitle:gsub("[^%w_%-]", "_")
    local fileName = sanitizedTitle.. ".mp4"
    local filePath = baseFolderPath.. "/".. fileName

    if writeToFile(filePath, videoData) then return filePath end
    return nil
end

function downloadInstagramVideo(url, callback)
    if not url then callback(nil, nil, "URL tidak valid") return end
    local apiUrl = "https://api.vreden.my.id/api/igdownload?url=".. URLEncoder.encode(url, "UTF-8")

    Http.get(apiUrl, {}, function(code, content)
        if code == 200 then
            local jsonResponse = cjson.decode(content)
            if jsonResponse and jsonResponse.result and jsonResponse.result.response and jsonResponse.result.response.data and #jsonResponse.result.response.data> 0 then
                local profile = jsonResponse.result.response.profile
                local statistics = jsonResponse.result.response.statistics
                local caption = jsonResponse.result.response.caption.text
                local videoData = jsonResponse.result.response.data[1]
                local videoUrl = videoData.url
                local title = profile.username.. " - ".. videoData.type

                -- Menampilkan detail video
                detailText.text = "📌 **Profil**: ".. profile.full_name.. "\n📷 **Username**: @".. profile.username..
                                  "\n❤️ **Likes**: ".. (statistics.like_count or "Tidak diketahui")..
                                  "\n▶️ **Tayangan**: ".. (statistics.play_count or "Tidak diketahui")..
                                  "\n💬 **Komentar**: ".. (statistics.comment_count or "Tidak diketahui")..
                                  "\n📜 **Caption**:\n".. caption

                service.speak("Detail video berhasil diperoleh.")

                -- Simpan detail untuk pengunduhan nanti
                saveButton.visibility = View.VISIBLE
                saveButton.onClick = function()
                    service.speak("Mengunduh dan menyimpan video...")
                    Http.get(videoUrl, {}, function(videoCode, videoContent)
                        if videoCode == 200 then
                            local savedPath = saveVideoToFile(videoContent, title)
                            if savedPath then
                                service.speak("Video telah disimpan di ".. savedPath)
                            else
                                service.speak("Gagal menyimpan video!")
                            end
                        else
                            service.speak("Gagal mengunduh video: ".. videoCode)
                        end
                    end)
                end
            else
                service.speak("Data API tidak sesuai")
            end
        else
            service.speak("Gagal mengakses API: ".. code)
        end
    end)
end

layout = {
    ScrollView,
    layout_width = "fill",
    layout_height = "fill",
    {
        LinearLayout,
orientation = "vertical",
        layout_width = "fill",
        padding = "16dp",
        layout_height = "wrap_content",
        {
            EditText,
            id = "urlInput",
            hint = "Masukkan URL Instagram",
            layout_width = "fill",
            layout_height = "wrap_content",
            inputType = InputType.TYPE_CLASS_TEXT
},
        {
            Button,
            id = "downloadButton",
            text = "Dapatkan Detail",
            layout_width = "fill",
            layout_height = "wrap_content"
},
        {
            TextView,
            id = "detailText",
            text = "",
            layout_width = "fill",
            layout_height = "wrap_content",
            padding = "10dp"
},
        {
            Button,
            id = "saveButton",
            text = "Simpan File",
            layout_width = "fill",
            layout_height = "wrap_content",
            visibility = View.GONE
}
}
}

dlg = LuaDialog(this)
dlg.setTitle("Pengunduh Video Instagram")
dlg.setView(loadlayout(layout))

downloadButton.onClick = function()
    local url = urlInput.text

    if #url == 0 then
        service.speak("Masukkan URL Instagram!") return
    end

    service.speak("Mengambil detail video...")

    downloadInstagramVideo(url, function() end)
end
-- Tombol untuk menutup dialog
dlg.setButton("Tutup", function()
    dlg.dismiss()
end)

dlg.show()
